@@ -9,16 +9,17 @@ from datetime import  datetime, timedelta
 def add_month(date, number):
     """Add a number of months to a date."""
     month = date.month - 1 + number
-    year = date.year + month / 12
-    month = month % 12 + 1
-    day = min(date.day, calendar.monthrange(year, month)[1])
-    return datetime(year, month, day, date.hour, date.minute, date.second,
-                    date.microsecond, date.tzinfo)
+    return update_month(date, month)
 
 
 def subtract_month(date, number):
     """Subtract a number of months from a date."""
     month = date.month - 1 - number
+    return update_month(date, month)
+
+
+def update_month(date, month):
+    """Create a new date with a modified number of months."""
     year = date.year + month / 12
     month = month % 12 + 1
     day = min(date.day, calendar.monthrange(year, month)[1])
@@ -110,6 +111,13 @@ class MutableDate(object):
 
     def weekday(self, number):
         """Mutate the original moment by changing the day of the week."""
+        weekday = self._date.isoweekday()
+        if number < 0:
+            days = abs(weekday - number)
+        else:
+            days = weekday - number
+        delta = self._date - timedelta(days)
+        self._date = delta
         return self
 
     def hours(self, number):
